
//--------------------------------------------------------------------------------------
// Global variables
//--------------------------------------------------------------------------------------
float4x4 g_WORLD;
float4x4 g_VIEW;
float4x4 g_PROJ; 
float4x4 g_VP;
float4 g_color;
float4 g_light;

//--------------------------------------------------------------------------------------
// Vertex shader output structure
//--------------------------------------------------------------------------------------
struct VS_OUTPUT
{
    float4 Position : POSITION; // vertex position 
    float4 Diffuse  : COLOR0;   // vertex diffuse color (note that COLOR0 is clamped from 0..1)
};

//--------------------------------------------------------------------------------------
// This shader computes standard transform and lighting
//--------------------------------------------------------------------------------------
VS_OUTPUT RenderSceneVS( float4 vPos : POSITION,float3 vNml:NORMAL)
{
    VS_OUTPUT Output;

    // Wϊ
    //vPos.x+=vNml.x;
    Output.Position = mul( vPos, g_WORLD );
    Output.Position = mul(Output.Position,g_VP);
    // _̐F̌
    float3 b;
    //b.x=g_light.x;
    //b.y=g_light.y;
    //b.z=g_light.z;
    b=g_light;
    
    b=normalize(b);
    float a = dot(vNml,b);
    
    Output.Diffuse = g_color;
    Output.Diffuse.x=0.5+a/2;
    Output.Diffuse.y=0.5+a/2;
    Output.Diffuse.z=1.0;

    return Output; 
}

VS_OUTPUT RenderWaterVS( float4 vPos : POSITION,float3 vNml:NORMAL)
{
    VS_OUTPUT Output;

    // Wϊ
    //vPos.x+=vNml.x;
    Output.Position = mul( vPos, g_WORLD );
    Output.Position = mul(Output.Position,g_VP);
    // _̐F̌
    float3 b;
    //b.x=g_light.x;
    //b.y=g_light.y;
    //b.z=g_light.z;
    b=g_light;
    
    b=normalize(b);
    float a = dot(vNml,b);
    
    Output.Diffuse = g_color;
    Output.Diffuse.x=a;
    Output.Diffuse.y=a;
    Output.Diffuse.z=a*2;

    return Output; 
}


//--------------------------------------------------------------------------------------
// Pixel shader output structure
//--------------------------------------------------------------------------------------
struct PS_OUTPUT
{
    float4 RGBColor : COLOR0; // Pixel color 
};

//--------------------------------------------------------------------------------------
// This shader outputs the pixel's color by modulating the texture's
// color with diffuse material color
//--------------------------------------------------------------------------------------
PS_OUTPUT RenderScenePS( VS_OUTPUT In ) 
{
    PS_OUTPUT Output;

    // Lookup mesh texture and modulate it with diffuse
    Output.RGBColor = In.Diffuse;

    return Output;
}



//--------------------------------------------------------------------------------------
// Renders scene 
//--------------------------------------------------------------------------------------
technique RenderScene
{
    pass P0
    { 
        VertexShader = compile vs_2_0 RenderSceneVS();
        PixelShader  = compile ps_2_0 RenderScenePS(); 
    }
}

technique RenderWater
{
    pass P0
    { 
        VertexShader = compile vs_2_0 RenderWaterVS();
        PixelShader  = compile ps_2_0 RenderScenePS(); 
    }
}